@@ -7,7 +7,8 @@ from responsibleai.modelanalysis import ModelAnalysis
 from responsibleai.rai_insights import ModelTask, RAIInsights
 
 from .__version__ import version
+from .feature_metadata import FeatureMetadata
 
 __version__ = version
 
-__all__ = ['ModelAnalysis', 'ModelTask', 'RAIInsights']
+__all__ = ['ModelAnalysis', 'ModelTask', 'RAIInsights', 'FeatureMetadata']
