@@ -16,6 +16,8 @@ from responsibleai._interfaces import (CausalData, CausalPolicy,
                                        CausalPolicyGains,
                                        CausalPolicyTreeInternal,
                                        CausalPolicyTreeLeaf, ComparisonTypes)
+from responsibleai._internal.constants import (FileFormats,
+                                               SerializationAttributes)
 from responsibleai._tools.causal.causal_config import CausalConfig
 from responsibleai._tools.causal.causal_constants import ResultAttributes
 from responsibleai._tools.shared.base_result import BaseResult
@@ -311,8 +313,9 @@ class CausalResult(BaseResult['CausalResult']):
     def _get_schema(cls, version: str):
         cls._validate_version(version)
 
-        schema_directory = Path(__file__).parent / 'dashboard_schemas'
-        schema_filename = f'schema_{version}.json'
+        schema_directory = Path(__file__).parent / \
+            SerializationAttributes.DASHBOARD_SCHEMAS
+        schema_filename = f'schema_{version}{FileFormats.JSON}'
         schema_filepath = schema_directory / schema_filename
         with open(schema_filepath, 'r') as f:
             return json.load(f)
