@@ -40,9 +40,8 @@ U_INITIALIZATION_EXAMPLES = '_initialization_examples'
 U_EVALUATION_EXAMPLES = '_evaluation_examples'
 FEATURES = 'features'
 CATEGORICAL_FEATURES = 'categorical_features'
-META_JSON = Metadata.META_JSON
-MODEL = Metadata.MODEL
 EXPLANATION = '_explanation'
+MAXIMUM_ROWS_FOR_GLOBAL_EXPLANATIONS = 10000
 
 
 class ExplainerManager(BaseManager):
@@ -141,7 +140,18 @@ class ExplainerManager(BaseManager):
             model_task=model_task,
             classes=self._classes,
             categorical_features=self._categorical_features)
-        return explainer.explain_global(data, include_local=local)
+
+        if len(data) <= MAXIMUM_ROWS_FOR_GLOBAL_EXPLANATIONS:
+            return explainer.explain_global(data, include_local=local)
+        else:
+            warnings.warn((
+                "LARGE-DATA-SCENARIO-DETECTED: "
+                "The data is larger than the supported limit of {0}. "
+                "Computing explanations for first {0} samples only.").format(
+                    MAXIMUM_ROWS_FOR_GLOBAL_EXPLANATIONS),
+                UserWarning)
+            return explainer.explain_global(data[
+                0:MAXIMUM_ROWS_FOR_GLOBAL_EXPLANATIONS], include_local=local)
 
     def compute(self):
         """Creates an explanation by running the explainer on the model."""
@@ -290,7 +300,7 @@ class ExplainerManager(BaseManager):
                     raise ValueError(
                         "Shape mismatch: local explanation"
                         "length differs from dataset")
-                if(len(local_dim) == 3 and
+                if (len(local_dim) == 3 and
                    (local_dim[2] != _feature_length or
                         local_dim[1] != _row_length)):
                     raise ValueError(
@@ -350,7 +360,7 @@ class ExplainerManager(BaseManager):
 
             meta = {IS_RUN: self._is_run,
                     IS_ADDED: self._is_added}
-            with open(data_directory / META_JSON, 'w') as file:
+            with open(data_directory / Metadata.META_JSON, 'w') as file:
                 json.dump(meta, file)
 
     @staticmethod
@@ -375,7 +385,7 @@ class ExplainerManager(BaseManager):
                 sub_directory_name=all_cf_dirs[0])
             data_directory = directory_manager.get_data_directory()
 
-            with open(data_directory / META_JSON, 'r') as meta_file:
+            with open(data_directory / Metadata.META_JSON, 'r') as meta_file:
                 meta = meta_file.read()
             meta = json.loads(meta)
             inst.__dict__['_' + IS_RUN] = meta[IS_RUN]
@@ -391,7 +401,7 @@ class ExplainerManager(BaseManager):
             inst.__dict__['_' + IS_ADDED] = False
             inst.__dict__[EXPLANATION] = None
 
-        inst.__dict__['_' + MODEL] = rai_insights.model
+        inst.__dict__['_' + Metadata.MODEL] = rai_insights.model
         inst.__dict__['_' + CLASSES] = rai_insights._classes
         inst.__dict__['_' + CATEGORICAL_FEATURES] = \
             rai_insights.categorical_features
