@@ -17,7 +17,9 @@ from erroranalysis._internal.process_categoricals import process_categoricals
 from raiutils.data_processing import convert_to_list
 from raiutils.models import SKLearn, is_classifier
 from responsibleai._interfaces import Dataset, RAIInsightsData
-from responsibleai._internal.constants import ManagerNames, Metadata
+from responsibleai._internal.constants import (FileFormats, ManagerNames,
+                                               Metadata,
+                                               SerializationAttributes)
 from responsibleai.exceptions import UserConfigValidationException
 from responsibleai.feature_metadata import FeatureMetadata
 from responsibleai.managers.causal_manager import CausalManager
@@ -28,25 +30,8 @@ from responsibleai.managers.explainer_manager import ExplainerManager
 from responsibleai.rai_insights.constants import ModelTask
 from responsibleai.rai_insights.rai_base_insights import RAIBaseInsights
 
-_PREDICTIONS = 'predictions'
-_TRAIN = 'train'
-_TEST = 'test'
-_TARGET_COLUMN = 'target_column'
-_TASK_TYPE = 'task_type'
-_CLASSES = 'classes'
-_FEATURE_COLUMNS = 'feature_columns'
-_FEATURE_METADATA = 'feature_metadata'
-_FEATURE_RANGES = 'feature_ranges'
-_CATEGORICAL_FEATURES = 'categorical_features'
-_CATEGORIES = 'categories'
-_CATEGORY_DICTIONARY = 'category_dictionary'
-_CATEGORICAL_INDEXES = 'categorical_indexes'
-_STRING_IND_DATA = 'string_ind_data'
-_META_JSON = Metadata.META_JSON
 _TRAIN_LABELS = 'train_labels'
-_JSON_EXTENSION = '.json'
-_PREDICT = 'predict'
-_PREDICT_PROBA = 'predict_proba'
+_MODEL = "model"
 _PREDICT_OUTPUT = 'predict_output'
 _PREDICT_PROBA_OUTPUT = 'predict_proba_output'
 _COLUMN_NAME = 'column_name'
@@ -54,7 +39,11 @@ _RANGE_TYPE = 'range_type'
 _UNIQUE_VALUES = 'unique_values'
 _MIN_VALUE = 'min_value'
 _MAX_VALUE = 'max_value'
-_MODEL = "model"
+_IDENTITY_FEATURE_NAME = 'identity_feature_name'
+_DATETIME_FEATURES = 'datetime_features'
+_TIME_SERIES_ID_FEATURES = 'time_series_id_features'
+_CATEGORICAL_FEATURES = 'categorical_features'
+_DROPPED_FEATURES = 'dropped_features'
 
 
 class RAIInsights(RAIBaseInsights):
@@ -64,8 +53,12 @@ class RAIInsights(RAIBaseInsights):
     single API.
     """
 
-    def __init__(self, model: Optional[Any], train: pd.DataFrame,
-                 test: pd.DataFrame, target_column: str, task_type: str,
+    def __init__(self,
+                 model: Optional[Any],
+                 train: pd.DataFrame,
+                 test: pd.DataFrame,
+                 target_column: str,
+                 task_type: str,
                  categorical_features: Optional[List[str]] = None,
                  classes: Optional[np.ndarray] = None,
                  serializer: Optional[Any] = None,
@@ -86,7 +79,10 @@ class RAIInsights(RAIBaseInsights):
             `regression`.
         :type task_type: str
         :param categorical_features: The categorical feature names.
-        :type categorical_features: list[str]
+            categorical_features is deprecated. Please provide categorical
+            features via the feature_metadata argument instead.
+            This argument will be removed after version 0.25
+        :type categorical_features: Optional[List[str]]
         :param classes: The class labels in the training dataset
         :type classes: numpy.ndarray
         :param serializer: Picklable custom serializer with save and load
@@ -101,15 +97,17 @@ class RAIInsights(RAIBaseInsights):
         :param feature_metadata: Feature metadata for the train/test
                                  dataset to identify different kinds
                                  of features in the dataset.
-        :type feature_metadata: FeatureMetadata
+        :type feature_metadata: Optional[FeatureMetadata]
         """
-        categorical_features = categorical_features or []
+        self._consolidate_categorical_features(
+            categorical_features, feature_metadata)
+
         if len(test) > maximum_rows_for_test:
-            warnings.warn("The size of test set {0} is greater than "
-                          "supported limit of {1}. Computing insights"
-                          " for first {1} samples of "
-                          "test set".format(len(test),
-                                            maximum_rows_for_test))
+            warnings.warn(f"The size of the test set {len(test)} is greater "
+                          "than the supported limit of "
+                          f"{maximum_rows_for_test}. Computing insights for "
+                          f"the first {maximum_rows_for_test} samples of "
+                          "the test set")
             self._large_test = test.copy()
             test = test.copy()[0:maximum_rows_for_test]
 
@@ -133,11 +131,9 @@ class RAIInsights(RAIBaseInsights):
         self._validate_rai_insights_input_parameters(
             model=model, train=train, test=test,
             target_column=target_column, task_type=task_type,
-            categorical_features=categorical_features,
             classes=classes,
             serializer=serializer,
-            maximum_rows_for_test=maximum_rows_for_test,
-            feature_metadata=feature_metadata)
+            feature_metadata=self._feature_metadata)
         self._classes = RAIInsights._get_classes(
             task_type=task_type,
             train=train,
@@ -147,11 +143,9 @@ class RAIInsights(RAIBaseInsights):
         self._feature_columns = \
             test.drop(columns=[target_column]).columns.tolist()
         self._feature_ranges = RAIInsights._get_feature_ranges(
-            test=test, categorical_features=categorical_features,
+            test=test, categorical_features=self.categorical_features,
             feature_columns=self._feature_columns)
-        self._feature_metadata = feature_metadata
 
-        self.categorical_features = categorical_features
         self._categories, self._categorical_indexes, \
             self._category_dictionary, self._string_ind_data = \
             process_categoricals(
@@ -221,6 +215,64 @@ class RAIInsights(RAIBaseInsights):
                         columns=self._feature_metadata.dropped_features,
                         axis=1)
 
+    def _consolidate_categorical_features(
+            self,
+            categorical_features: Optional[List[str]],
+            feature_metadata: Optional[FeatureMetadata]):
+        """Consolidates the categorical features.
+
+        Originally, only the RAIInsights constructor accepted
+        categorical_features. Later on, feature_metadata was added as an
+        argument that also includes categorical_features.
+        This method consolidates them or raises an exception if it is not
+        possible. The resulting categorical features should be set on the
+        self._feature_metadata object. Eventually, the categorical_features
+        argument on the RAIInsights constructor will be removed at which
+        point this method can be removed as well.
+
+        :param categorical_features: the categorical features from the
+            RAIInsights constructor
+        :type categorical_features: Optional[List[str]]
+        :param feature_metadata: the feature metadata specified which may
+            include information on categorical features
+        :type feature_metadata: Optional[FeatureMetadata]
+        """
+        consolidated_categorical_features = []
+        if categorical_features is not None:
+            warnings.warn("The categorical_features argument on the "
+                          "RAIInsights constructor is deprecated and will "
+                          "be removed after version 0.26. Please provide "
+                          "categorical features via the feature_metadata "
+                          "argument instead.")
+        if feature_metadata is None:
+            # initialize to avoid having to keep checking if it is None
+            feature_metadata = FeatureMetadata()
+        if feature_metadata.categorical_features is None:
+            if categorical_features is None:
+                consolidated_categorical_features = []
+            else:
+                consolidated_categorical_features = categorical_features
+        else:
+            if categorical_features is None:
+                consolidated_categorical_features = \
+                    feature_metadata.categorical_features
+            else:
+                # Both are specified. Raise an exception if they don't match.
+                if (set(categorical_features) ==
+                        set(feature_metadata.categorical_features)):
+                    consolidated_categorical_features = categorical_features
+                else:
+                    raise UserConfigValidationException(
+                        'The categorical_features provided via the '
+                        'RAIInsights constructor and the categorical_features '
+                        'provided via the feature_metadata argument do not '
+                        'match.')
+        # set the consolidated result on both fields uniformly
+        self.categorical_features = consolidated_categorical_features
+        self._feature_metadata = feature_metadata
+        self._feature_metadata.categorical_features = \
+            consolidated_categorical_features
+
     def _initialize_managers(self):
         """Initializes the managers.
 
@@ -281,19 +333,22 @@ class RAIInsights(RAIBaseInsights):
         Add data balance measures to be computed on categorical features
         if it is a classification task.
         """
-        if self.task_type == ModelTask.CLASSIFICATION and \
-                len(self.categorical_features) > 0 and \
-                self._classes is not None:
+        if (self.task_type == ModelTask.CLASSIFICATION and
+                len(self.categorical_features) > 0 and
+                self._classes is not None):
             self._data_balance_manager.add(
                 cols_of_interest=self.categorical_features)
 
     def _validate_rai_insights_input_parameters(
-            self, model: Any, train: pd.DataFrame, test: pd.DataFrame,
-            target_column: str, task_type: str,
-            categorical_features: List[str], classes: np.ndarray,
+            self,
+            model: Any,
+            train: pd.DataFrame,
+            test: pd.DataFrame,
+            target_column: str,
+            task_type: str,
+            classes: np.ndarray,
             serializer,
-            maximum_rows_for_test: int,
-            feature_metadata: Optional[FeatureMetadata] = None):
+            feature_metadata: FeatureMetadata):
         """Validate the inputs for the RAIInsights constructor.
 
         :param model: The model to compute RAI insights for.
@@ -309,8 +364,6 @@ class RAIInsights(RAIBaseInsights):
         :param task_type: The task to run, can be `classification` or
             `regression`.
         :type task_type: str
-        :param categorical_features: The categorical feature names.
-        :type categorical_features: list[str]
         :param classes: The class labels in the training dataset
         :type classes: numpy.ndarray
         :param serializer: Picklable custom serializer with save and load
@@ -318,9 +371,6 @@ class RAIInsights(RAIBaseInsights):
             method returns a dictionary state and load method returns the
             model.
         :type serializer: object
-        :param maximum_rows_for_test: Limit on size of test data
-            (for performance reasons)
-        :type maximum_rows_for_test: int
         :param feature_metadata: Feature metadata for the train/test
                                  dataset to identify different kinds
                                  of features in the dataset.
@@ -369,20 +419,21 @@ class RAIInsights(RAIBaseInsights):
                     'and test sets.'
                 )
 
-            if len(set(train.columns) - set(test.columns)) != 0 or \
-                    len(set(test.columns) - set(train.columns)) != 0:
+            if (len(set(train.columns) - set(test.columns)) != 0 or
+                    len(set(test.columns) - set(train.columns)) != 0):
                 raise UserConfigValidationException(
                     'The features in train and test data do not match')
 
-            if target_column not in list(train.columns) or \
-                    target_column not in list(test.columns):
+            if (target_column not in list(train.columns) or
+                    target_column not in list(test.columns)):
                 raise UserConfigValidationException(
                     'Target name {0} not present in train/test data'.format(
                         target_column)
                 )
 
-            if categorical_features is not None and \
-                    len(categorical_features) > 0:
+            categorical_features = feature_metadata.categorical_features
+            if (categorical_features is not None and
+                    len(categorical_features) > 0):
                 if target_column in categorical_features:
                     raise UserConfigValidationException(
                         'Found target name {0} in '
@@ -403,8 +454,8 @@ class RAIInsights(RAIBaseInsights):
                         np.unique(train[column])
                     except Exception:
                         raise UserConfigValidationException(
-                            "Error finding unique values in column {0}. "
-                            "Please check your train data.".format(column)
+                            f"Error finding unique values in column {column}."
+                            " Please check your train data."
                         )
 
                     try:
@@ -420,39 +471,33 @@ class RAIInsights(RAIBaseInsights):
                 columns=[target_column]).select_dtypes(
                     include='number').columns.tolist()
             string_features_set = set(train_features) - set(numeric_features)
-            if len(string_features_set - set(categorical_features)) > 0:
+            non_categorical_string_columns = \
+                string_features_set - set(categorical_features)
+            if len(non_categorical_string_columns) > 0:
                 raise UserConfigValidationException(
                     "The following string features were not "
-                    "identified as categorical features: {0}".format(
-                        string_features_set - set(categorical_features))
-                )
+                    "identified as categorical features: "
+                    f"{non_categorical_string_columns}")
 
-            if classes is not None and task_type == \
-                    ModelTask.CLASSIFICATION:
-                if len(set(train[target_column].unique()) -
-                       set(classes)) != 0 or \
+            if classes is not None and task_type == ModelTask.CLASSIFICATION:
+                if (len(set(train[target_column].unique()) -
+                        set(classes)) != 0 or
                         len(set(classes) -
-                            set(train[target_column].unique())) != 0:
+                            set(train[target_column].unique())) != 0):
                     raise UserConfigValidationException(
                         'The train labels and distinct values in '
                         'target (train data) do not match')
 
-                if len(set(test[target_column].unique()) -
-                       set(classes)) != 0 or \
+                if (len(set(test[target_column].unique()) -
+                        set(classes)) != 0 or
                         len(set(classes) -
-                            set(test[target_column].unique())) != 0:
+                            set(test[target_column].unique())) != 0):
                     raise UserConfigValidationException(
                         'The train labels and distinct values in '
                         'target (test data) do not match')
 
-            if feature_metadata is not None:
-                if not isinstance(feature_metadata, FeatureMetadata):
-                    raise UserConfigValidationException(
-                        "Expecting type FeatureMetadata but got {0}".format(
-                            type(feature_metadata)))
-
-                feature_metadata.validate_feature_metadata_with_user_features(
-                    list(train.columns))
+            self._validate_feature_metadata(
+                feature_metadata, train, task_type)
 
             if model is not None:
                 # Pick one row from train and test data
@@ -460,8 +505,8 @@ class RAIInsights(RAIBaseInsights):
                 small_test_data = test[0:1]
                 has_dropped_features = False
                 if feature_metadata is not None:
-                    if feature_metadata.dropped_features is not None and \
-                            len(feature_metadata.dropped_features) != 0:
+                    if (feature_metadata.dropped_features is not None and
+                            len(feature_metadata.dropped_features) != 0):
                         has_dropped_features = True
                         small_train_data = small_train_data.drop(
                             columns=feature_metadata.dropped_features, axis=1)
@@ -472,8 +517,8 @@ class RAIInsights(RAIBaseInsights):
                     columns=[target_column], axis=1)
                 small_test_data = small_test_data.drop(
                     columns=[target_column], axis=1)
-                if len(small_train_data.columns) == 0 or \
-                        len(small_test_data.columns) == 0:
+                if (len(small_train_data.columns) == 0 or
+                        len(small_test_data.columns) == 0):
                     if has_dropped_features:
                         raise UserConfigValidationException(
                             'All features have been dropped from the dataset.'
@@ -494,7 +539,7 @@ class RAIInsights(RAIBaseInsights):
                     model.predict(small_test_data)
                 except Exception:
                     raise UserConfigValidationException(
-                        'The model passed cannot be used for'
+                        'The passed model cannot be used for'
                         ' getting predictions via predict()'
                     )
                 self._validate_features_same(small_train_features_before,
@@ -508,7 +553,7 @@ class RAIInsights(RAIBaseInsights):
                         model.predict_proba(small_test_data)
                     except Exception:
                         raise UserConfigValidationException(
-                            'The model passed cannot be used for'
+                            'The passed model cannot be used for'
                             ' getting predictions via predict_proba()'
                         )
                 self._validate_features_same(small_train_features_before,
@@ -518,7 +563,7 @@ class RAIInsights(RAIBaseInsights):
                 if task_type == ModelTask.REGRESSION:
                     if hasattr(model, SKLearn.PREDICT_PROBA):
                         raise UserConfigValidationException(
-                            'The regression model'
+                            'The regression model '
                             'provided has a predict_proba function. '
                             'Please check the task_type.')
         else:
@@ -527,6 +572,33 @@ class RAIInsights(RAIBaseInsights):
                 "Expecting pandas DataFrame for train and test."
             )
 
+    def _validate_feature_metadata(self, feature_metadata, train, task_type):
+        if feature_metadata is not None:
+            if not isinstance(feature_metadata, FeatureMetadata):
+                raise UserConfigValidationException(
+                    "Expecting type FeatureMetadata but got "
+                    f"{type(feature_metadata)}")
+
+            feature_names = list(train.columns)
+            feature_metadata.validate_feature_metadata_with_user_features(
+                feature_names)
+
+            if task_type != ModelTask.FORECASTING:
+                if feature_metadata.time_series_id_features:
+                    raise UserConfigValidationException(
+                        "The specified metadata time_series_id_features "
+                        "is only supported for the forecasting task type.")
+
+                if feature_metadata.datetime_features:
+                    raise UserConfigValidationException(
+                        "The specified metadata datetime_features "
+                        "is only supported for the forecasting task type.")
+            elif (feature_metadata.datetime_features and
+                    len(feature_metadata.datetime_features) > 1):
+                raise UserConfigValidationException(
+                    "Only a single datetime feature is supported at "
+                    "this point.")
+
     def _validate_features_same(self, small_train_features_before,
                                 small_train_data, function):
         """
@@ -542,11 +614,11 @@ class RAIInsights(RAIBaseInsights):
         """
         small_train_features_after = list(small_train_data.columns)
         if small_train_features_before != small_train_features_after:
-            raise UserConfigValidationException(
-                ('Calling model {} function modifies '
-                 'input dataset features. Please check if '
-                 'predict function is defined correctly.').format(function)
-            )
+            exc_msg = (
+                f'Calling model {function} function modifies input dataset'
+                f' features. Please check if {function} function is '
+                'defined correctly.')
+            raise UserConfigValidationException(exc_msg)
 
     @property
     def causal(self) -> CausalManager:
@@ -681,8 +753,8 @@ class RAIInsights(RAIBaseInsights):
                 metadata_exists = metadata is not None
                 dropped_features_exist = metadata_exists and \
                     metadata.dropped_features is not None
-                if dropped_features_exist and \
-                        len(metadata.dropped_features) != 0:
+                if (dropped_features_exist and
+                        len(metadata.dropped_features) != 0):
                     predict_dataset = predict_dataset.drop(
                         metadata.dropped_features, axis=1)
                 predicted_y = self.model.predict(predict_dataset)
@@ -696,7 +768,7 @@ class RAIInsights(RAIBaseInsights):
                 raise ValueError(
                     "Model prediction output of unsupported type,") from ex
         if predicted_y is not None:
-            if(self.task_type == "classification" and
+            if (self.task_type == "classification" and
                     dashboard_dataset.class_names is not None):
                 predicted_y = [dashboard_dataset.class_names.index(
                     y) for y in predicted_y]
@@ -720,7 +792,7 @@ class RAIInsights(RAIBaseInsights):
         true_y = self.test[self.target_column]
 
         if true_y is not None and len(true_y) == row_length:
-            if(self.task_type == "classification" and
+            if (self.task_type == "classification" and
                dashboard_dataset.class_names is not None):
                 true_y = [dashboard_dataset.class_names.index(
                     y) for y in true_y]
@@ -743,8 +815,8 @@ class RAIInsights(RAIBaseInsights):
                 metadata_exists = metadata is not None
                 dropped_features_exist = metadata_exists and \
                     metadata.dropped_features is not None
-                if dropped_features_exist and \
-                        len(metadata.dropped_features) != 0:
+                if (dropped_features_exist and
+                        len(metadata.dropped_features) != 0):
                     predict_dataset = predict_dataset.drop(
                         metadata.dropped_features, axis=1)
                 probability_y = self.model.predict_proba(predict_dataset)
@@ -766,38 +838,36 @@ class RAIInsights(RAIBaseInsights):
         :param path: The directory path to save the RAIInsights to.
         :type path: str
         """
-        prediction_output_path = Path(path) / _PREDICTIONS
+        prediction_output_path = (
+            Path(path) /
+            SerializationAttributes.PREDICTIONS_DIRECTORY)
         prediction_output_path.mkdir(parents=True, exist_ok=True)
 
         if self.model is None:
             return
 
         self._write_to_file(
-            prediction_output_path / (_PREDICT + _JSON_EXTENSION),
+            prediction_output_path / SerializationAttributes.PREDICT_JSON,
             json.dumps(self.predict_output.tolist()))
 
         if self.predict_proba_output is not None:
             self._write_to_file(
-                prediction_output_path / (_PREDICT_PROBA + _JSON_EXTENSION),
+                prediction_output_path /
+                SerializationAttributes.PREDICT_PROBA_JSON,
                 json.dumps(self.predict_proba_output.tolist()))
 
         if self._large_test is not None:
             self._write_to_file(
-                prediction_output_path / (
-                    'large_' + _PREDICT + _JSON_EXTENSION),
+                prediction_output_path /
+                SerializationAttributes.LARGE_PREDICT_JSON,
                 json.dumps(self._large_predict_output.tolist()))
 
             if self._large_predict_proba_output is not None:
                 self._write_to_file(
-                    prediction_output_path / (
-                        'large_' + _PREDICT_PROBA + _JSON_EXTENSION),
+                    prediction_output_path /
+                    SerializationAttributes.LARGE_PREDICT_PROBA_JSON,
                     json.dumps(self._large_predict_proba_output.tolist()))
 
-            # Save large test data
-            self._write_to_file(
-                prediction_output_path / ('large_' + _TEST + _JSON_EXTENSION),
-                self._large_test.to_json(orient='split'))
-
     def _save_large_data(self, path):
         """Save the large data.
 
@@ -806,8 +876,10 @@ class RAIInsights(RAIBaseInsights):
         """
         if self._large_test is not None:
             # Save large test data
-            large_test_path = Path(path) / 'data' / (
-                'large_' + _TEST + _JSON_EXTENSION)
+            large_test_path = (
+                Path(path) /
+                SerializationAttributes.DATA_DIRECTORY /
+                SerializationAttributes.LARGE_TEST_JSON)
             self._write_to_file(
                 large_test_path,
                 self._large_test.to_json(orient='split'))
@@ -824,16 +896,21 @@ class RAIInsights(RAIBaseInsights):
         feature_metadata_dict = None
         if self._feature_metadata is not None:
             feature_metadata_dict = self._feature_metadata.to_dict()
+        if self._large_test is not None:
+            number_large_test_samples = len(self._large_test)
+        else:
+            number_large_test_samples = len(self.test)
         meta = {
-            _TARGET_COLUMN: self.target_column,
-            _TASK_TYPE: self.task_type,
-            _CATEGORICAL_FEATURES: self.categorical_features,
-            _CLASSES: classes,
-            _FEATURE_COLUMNS: self._feature_columns,
-            _FEATURE_RANGES: self._feature_ranges,
-            _FEATURE_METADATA: feature_metadata_dict
+            Metadata.TARGET_COLUMN: self.target_column,
+            Metadata.TASK_TYPE: self.task_type,
+            Metadata.CATEGORICAL_FEATURES: self.categorical_features,
+            Metadata.CLASSES: classes,
+            Metadata.FEATURE_COLUMNS: self._feature_columns,
+            Metadata.FEATURE_RANGES: self._feature_ranges,
+            Metadata.FEATURE_METADATA: feature_metadata_dict,
+            Metadata.NUMBER_LARGE_TEST_SAMPLES: number_large_test_samples
         }
-        with open(top_dir / _META_JSON, 'w') as file:
+        with open(top_dir / Metadata.META_JSON, 'w') as file:
             json.dump(meta, file)
 
     def save(self, path):
@@ -851,16 +928,14 @@ class RAIInsights(RAIBaseInsights):
         for all columns"""
         result = []
         for col in feature_columns:
-            res_object = {}
-            if (col in categorical_features):
+            res_object = {_COLUMN_NAME: col}
+            if col in categorical_features:
                 unique_value = test[col].unique()
-                res_object[_COLUMN_NAME] = col
                 res_object[_RANGE_TYPE] = "categorical"
                 res_object[_UNIQUE_VALUES] = unique_value.tolist()
             else:
                 min_value = float(test[col].min())
                 max_value = float(test[col].max())
-                res_object[_COLUMN_NAME] = col
                 res_object[_RANGE_TYPE] = "integer"
                 res_object[_MIN_VALUE] = min_value
                 res_object[_MAX_VALUE] = max_value
@@ -877,49 +952,58 @@ class RAIInsights(RAIBaseInsights):
         :type path: str
         """
         top_dir = Path(path)
-        with open(top_dir / _META_JSON, 'r') as meta_file:
+        with open(top_dir / Metadata.META_JSON, 'r') as meta_file:
             meta = meta_file.read()
         meta = json.loads(meta)
-        inst.__dict__[_TARGET_COLUMN] = meta[_TARGET_COLUMN]
-        inst.__dict__[_TASK_TYPE] = meta[_TASK_TYPE]
-        inst.__dict__[_CATEGORICAL_FEATURES] = meta[_CATEGORICAL_FEATURES]
+        inst.__dict__[Metadata.TARGET_COLUMN] = meta[Metadata.TARGET_COLUMN]
+        inst.__dict__[Metadata.TASK_TYPE] = meta[Metadata.TASK_TYPE]
+        inst.__dict__[Metadata.CATEGORICAL_FEATURES] = \
+            meta[Metadata.CATEGORICAL_FEATURES]
         classes = None
         if _TRAIN_LABELS in meta:
             classes = meta[_TRAIN_LABELS]
         else:
-            classes = meta[_CLASSES]
+            classes = meta[Metadata.CLASSES]
 
-        inst.__dict__['_' + _CLASSES] = RAIInsights._get_classes(
-            task_type=meta[_TASK_TYPE],
-            train=inst.__dict__[_TRAIN],
-            target_column=meta[_TARGET_COLUMN],
+        inst.__dict__['_' + Metadata.CLASSES] = RAIInsights._get_classes(
+            task_type=meta[Metadata.TASK_TYPE],
+            train=inst.__dict__[Metadata.TRAIN],
+            target_column=meta[Metadata.TARGET_COLUMN],
             classes=classes
         )
 
-        inst.__dict__['_' + _FEATURE_COLUMNS] = meta[_FEATURE_COLUMNS]
-        inst.__dict__['_' + _FEATURE_RANGES] = meta[_FEATURE_RANGES]
-        if _FEATURE_METADATA not in meta or meta[_FEATURE_METADATA] is None:
-            inst.__dict__['_' + _FEATURE_METADATA] = None
+        inst.__dict__['_' + Metadata.FEATURE_COLUMNS] = \
+            meta[Metadata.FEATURE_COLUMNS]
+        inst.__dict__['_' + Metadata.FEATURE_RANGES] = \
+            meta[Metadata.FEATURE_RANGES]
+        if (Metadata.FEATURE_METADATA not in meta or
+                meta[Metadata.FEATURE_METADATA] is None):
+            inst.__dict__['_' + Metadata.FEATURE_METADATA] = FeatureMetadata()
         else:
-            inst.__dict__['_' + _FEATURE_METADATA] = FeatureMetadata(
-                identity_feature_name=meta[_FEATURE_METADATA][
-                    'identity_feature_name'],
-                datetime_features=meta[_FEATURE_METADATA][
-                    'datetime_features'],
-                categorical_features=meta[_FEATURE_METADATA][
-                    'categorical_features'],
-                dropped_features=meta[_FEATURE_METADATA][
-                    'dropped_features'],)
+            inst.__dict__['_' + Metadata.FEATURE_METADATA] = FeatureMetadata(
+                identity_feature_name=meta[Metadata.FEATURE_METADATA][
+                    _IDENTITY_FEATURE_NAME],
+                datetime_features=meta[Metadata.FEATURE_METADATA][
+                    _DATETIME_FEATURES],
+                time_series_id_features=meta[Metadata.FEATURE_METADATA][
+                    _TIME_SERIES_ID_FEATURES],
+                categorical_features=meta[Metadata.FEATURE_METADATA][
+                    _CATEGORICAL_FEATURES],
+                dropped_features=meta[Metadata.FEATURE_METADATA][
+                    _DROPPED_FEATURES],)
 
-        inst.__dict__['_' + _CATEGORIES], \
-            inst.__dict__['_' + _CATEGORICAL_INDEXES], \
-            inst.__dict__['_' + _CATEGORY_DICTIONARY], \
-            inst.__dict__['_' + _STRING_IND_DATA] = \
+        all_features_names = inst.__dict__['_' + Metadata.FEATURE_COLUMNS]
+        categorical_features = inst.__dict__[Metadata.CATEGORICAL_FEATURES]
+        dataset = inst.__dict__[Metadata.TEST].drop(
+            columns=[inst.__dict__[Metadata.TARGET_COLUMN]])
+        inst.__dict__['_' + Metadata.CATEGORIES], \
+            inst.__dict__['_' + Metadata.CATEGORICAL_INDEXES], \
+            inst.__dict__['_' + Metadata.CATEGORY_DICTIONARY], \
+            inst.__dict__['_' + Metadata.STRING_IND_DATA] = \
             process_categoricals(
-                all_feature_names=inst.__dict__['_' + _FEATURE_COLUMNS],
-                categorical_features=inst.__dict__[_CATEGORICAL_FEATURES],
-                dataset=inst.__dict__[_TEST].drop(columns=[
-                    inst.__dict__[_TARGET_COLUMN]]))
+                all_feature_names=all_features_names,
+                categorical_features=categorical_features,
+                dataset=dataset)
 
     @staticmethod
     def _load_predictions(inst, path):
@@ -935,37 +1019,26 @@ class RAIInsights(RAIBaseInsights):
             inst.__dict__[_PREDICT_PROBA_OUTPUT] = None
             return
 
-        prediction_output_path = Path(path) / _PREDICTIONS
+        prediction_output_path = (
+            Path(path) /
+            SerializationAttributes.PREDICTIONS_DIRECTORY)
 
         with open(prediction_output_path / (
-                _PREDICT + _JSON_EXTENSION), 'r') as file:
+                SerializationAttributes.PREDICT_JSON), 'r') as file:
             predict_output = json.load(file)
         inst.__dict__[_PREDICT_OUTPUT] = np.array(predict_output)
 
-        if inst.__dict__[_TASK_TYPE] == ModelTask.CLASSIFICATION:
+        if inst.__dict__[Metadata.TASK_TYPE] == ModelTask.CLASSIFICATION:
             with open(prediction_output_path / (
-                    _PREDICT_PROBA + _JSON_EXTENSION), 'r') as file:
+                    SerializationAttributes.PREDICT_PROBA_JSON), 'r') as file:
                 predict_proba_output = json.load(file)
             inst.__dict__[_PREDICT_PROBA_OUTPUT] = np.array(
                 predict_proba_output)
         else:
             inst.__dict__[_PREDICT_PROBA_OUTPUT] = None
 
-        large_test_path = prediction_output_path / (
-            'large_' + _TEST + _JSON_EXTENSION)
-        if large_test_path.exists():
-            data_directory = Path(path) / "data"
-            with open(data_directory / (
-                    _TEST + 'dtypes' + _JSON_EXTENSION), 'r') as file:
-                types = json.load(file)
-            with open(large_test_path, 'r') as file:
-                inst.__dict__["_large_test"] = \
-                    pd.read_json(file, dtype=types, orient='split')
-        else:
-            inst.__dict__["_large_test"] = None
-
         large_predict_output_path = prediction_output_path / (
-            'large_' + _PREDICT + _JSON_EXTENSION)
+            SerializationAttributes.LARGE_PREDICT_JSON)
         if large_predict_output_path.exists():
             with open(large_predict_output_path, 'r') as file:
                 large_predict_output = json.load(file)
@@ -975,7 +1048,7 @@ class RAIInsights(RAIBaseInsights):
             inst.__dict__["_large_predict_output"] = None
 
         large_predict_proba_output_path = prediction_output_path / (
-            'large_' + _PREDICT_PROBA + _JSON_EXTENSION)
+            SerializationAttributes.LARGE_PREDICT_PROBA_JSON)
         if large_predict_proba_output_path.exists():
             with open(large_predict_proba_output_path, 'r') as file:
                 large_predict_proba_output = json.load(file)
@@ -993,12 +1066,18 @@ class RAIInsights(RAIBaseInsights):
         :param path: The directory path to data location.
         :type path: str
         """
-        large_test_path = Path(path) / 'data' / (
-            'large_' + _TEST + _JSON_EXTENSION)
+        large_test_path = (
+            Path(path) /
+            SerializationAttributes.DATA_DIRECTORY /
+            SerializationAttributes.LARGE_TEST_JSON)
         if large_test_path.exists():
-            data_directory = Path(path) / "data"
-            with open(data_directory / (
-                    _TEST + 'dtypes' + _JSON_EXTENSION), 'r') as file:
+            data_directory = (
+                Path(path) /
+                SerializationAttributes.DATA_DIRECTORY)
+            with open(
+                data_directory / (
+                    Metadata.TEST + 'dtypes' + FileFormats.JSON),
+                    'r') as file:
                 types = json.load(file)
             with open(large_test_path, 'r') as file:
                 inst.__dict__["_large_test"] = \
