@@ -2,6 +2,7 @@
 # Licensed under the MIT License.
 
 import pandas as pd
+import pytest
 
 from responsibleai.databalanceanalysis import FeatureBalanceMeasures
 
@@ -53,3 +54,19 @@ class TestFeatureBalanceMeasures:
                 drop=True
             ),
         )
+
+    def test_col_less_than_two_unique_values(self, singular_valued_col_data):
+        col_of_interest = "col1"
+        target_feature = "target"
+        pos_label = 1
+
+        warn_text = (f"Column '{col_of_interest}' has less than 2 unique"
+                     " values, so feature balance measures for"
+                     f" {target_feature}=={pos_label} are not being computed"
+                     " for this column.")
+        with pytest.warns(UserWarning, match=warn_text):
+            FeatureBalanceMeasures(
+                cols_of_interest=[col_of_interest],
+                label_col=target_feature,
+                pos_label=pos_label,
+            ).measures(singular_valued_col_data)
