@@ -8,13 +8,16 @@ from tempfile import TemporaryDirectory
 import numpy as np
 import pandas as pd
 import pytest
-from tests.common_utils import (create_adult_income_dataset,
-                                create_binary_classification_dataset,
-                                create_complex_classification_pipeline,
-                                create_iris_data, create_lightgbm_classifier)
+from tests.common_utils import create_adult_income_dataset, create_iris_data
 
+from rai_test_utils.datasets.tabular import \
+    create_binary_classification_dataset
+from rai_test_utils.models.lightgbm import create_lightgbm_classifier
+from rai_test_utils.models.sklearn import \
+    create_complex_classification_pipeline
 from responsibleai import ModelTask, RAIInsights
-from responsibleai._internal.constants import ManagerNames
+from responsibleai._internal.constants import (ManagerNames,
+                                               SerializationAttributes)
 from responsibleai.feature_metadata import FeatureMetadata
 
 LABELS = 'labels'
@@ -198,7 +201,8 @@ class TestRAIInsightsSaveAndLoadScenarios(object):
 
             # Remove the model.pkl file to cause an exception to occur
             # while loading the model.
-            model_pkl_path = Path(tmpdir) / "rai_insights" / "model.pkl"
+            model_pkl_path = Path(tmpdir) / \
+                "rai_insights" / SerializationAttributes.MODEL_PKL
             os.remove(model_pkl_path)
             with pytest.raises(Exception):
                 RAIInsights.load(save_path)
@@ -299,6 +303,11 @@ def validate_rai_insights(
     if feature_columns is not None:
         assert rai_insights._feature_columns == (feature_columns or [])
     if feature_metadata is not None:
+        # mismatch between categorical_features passed in RAIInsights
+        # constructor and the categorical_features set on the feature_metadata
+        if (categorical_features is not None and
+                feature_metadata.categorical_features is None):
+            feature_metadata.categorical_features = categorical_features
         assert rai_insights._feature_metadata == feature_metadata
     assert target_column not in rai_insights._feature_columns
 
